@@ -404,6 +404,15 @@ class LoadMaster(HttpClient):
             self.version = ".".join(value.split("."[:3]))
         return value
 
+    def get_all_parameters(self):
+        """ Return all parameters as a dict with lowercase keys
+
+        :return: A dict of all the parameters, with the keys lowercased
+        """
+        response = self._get('/getall')
+        data = get_data(response)
+        return dict((k.lower(), v) for k, v in data.items())
+
     def enable_api(self):
         """enable LoadMaster API"""
         # Can't use the HttpClient methods for this as the
